@@ -23,10 +23,19 @@ slopeHeuristic <- function(mod){
   # the new penalized likelihood
   llpen = main_data$LL- 2* fit_coef[2]*main_data$complexity
   SH = 2* llpen
+
+  if (nlevels(main_data$model)<2){
   plot(main_data$complexity,main_data$LL,type='p',xlab='Model dimension',ylab='Log-likelihood')
   abline(fit,col='red')
   plot(main_data$K,llpen,type='p',xlab='K',ylab='Penalized log-likelihood')
   points(main_data$K[which.max(llpen)],max(llpen),pch=19,col='red')
   return(main_data$K[which.max(llpen)])
+  }else{
+    plot(main_data$complexity,main_data$LL,type='p',xlab='Model dimension',ylab='Log-likelihood')
+    abline(fit,col='red')
+    plot(main_data$rank,llpen,type='p',xlab='Rank of the model',ylab='Penalized log-likelihood')
+    points(main_data$rank[which.max(llpen)],max(llpen),pch=19,col='red')
+    return(main_data$rank[which.max(llpen)])
+  }
 }
 
